@@ -1,14 +1,12 @@
-import json
 import os
 os.environ['TF_CPP_MIN_LOG_LEVEL'] = '2' 
 import tensorflow as tf
 tf.get_logger().setLevel('ERROR')
 tf.compat.v1.logging.set_verbosity(tf.compat.v1.logging.ERROR) 
-from PIL import Image, ImageDraw
+from PIL import Image
 import numpy as np 
 import cv2
-import functools
-import sys
+
 from IPython.display import display
 import random
 import io
@@ -16,13 +14,6 @@ import io
 from object_detection.utils import dataset_util
 from object_detection.utils import config_util
 from object_detection.utils import label_map_util
-from tensorboard.backend.event_processing.event_accumulator import EventAccumulator
-from object_detection.builders import dataset_builder
-from object_detection.builders import graph_rewriter_builder    
-from object_detection.builders import model_builder
-from object_detection.legacy import trainer
-from object_detection.legacy import evaluator
-from object_detection import exporter
 from object_detection.utils import ops as utils_ops
 from object_detection.utils import visualization_utils as vis_util
 from object_detection import exporter_lib_v2
@@ -30,10 +21,9 @@ from object_detection.protos import pipeline_pb2
 from object_detection import model_lib_v2
 from tensorflow.python.summary.summary_iterator import summary_iterator
 from google.protobuf import text_format
-from object_detection.protos import optimizer_pb2
 from object_detection.core import data_parser
 from object_detection.core import standard_fields as fields
-from object_detection.metrics.tf_example_parser import BoundingBoxParser, StringParser, Int64Parser, FloatParser
+from object_detection.metrics.tf_example_parser import BoundingBoxParser, StringParser, Int64Parser
 
 
 def create_record_files(dict_annotations, train_list, train_list_id, eval_list, 
